#!/bin/bash

set -e

BRANCH_NAME="master"
WIKITEXT_TAG="wikitext.core-3.0.29"
FETCHED_SOURCES_NAME="eclipse-mylyn-${BRANCH_NAME}-fetched-src"

#clean up old runs
rm -rf ${FETCHED_SOURCES_NAME}

# checkout aggregator repo
git clone --recursive git://git.eclipse.org/gitroot/mylyn/org.eclipse.mylyn.all.git ${FETCHED_SOURCES_NAME}
cd ${FETCHED_SOURCES_NAME}
git checkout ${BRANCH_NAME}
git submodule update

#checkout wikitext
pushd org.eclipse.mylyn.docs >/dev/null
git checkout ${WIKITEXT_TAG}
popd >/dev/null

# update from BRANCH_NAME branch to get latest - note that org.eclipse.mylyn.docs don't have this branch
for i in org.eclipse.mylyn{,.builds,.commons,.context,.reviews,.tasks,.versions} ; do
  pushd $i >/dev/null
    echo "Pull latest from ${BRANCH_NAME} into $i ... "
    git checkout ${BRANCH_NAME}
  popd >/dev/null
done

# remove precompiled binaries
find . -type f -name "*.class" -o -name "*.jar" -exec rm {} \;

# purge git metadata
rm -rf .git
find . -type f -name ".gitignore" -exec rm {} \;
find . -type f -name ".gitmodules" -exec rm {} \;

cd ..

#package and clean up
tar -caf ${FETCHED_SOURCES_NAME}.tar.xz ${FETCHED_SOURCES_NAME}
rm -rf ${FETCHED_SOURCES_NAME}
